CoordRefSystem

Enum CoordRefSystem 

#[non_exhaustive]
pub enum CoordRefSystem { Wgs84, }
The reference system of the provided coordinates.

Currently only the WGS-84 coordinate reference system is supported. It defines the latitude and longitude of the GeoUri to be in decimal degrees and the altitude in meters.

For more details see the component description in RFC 5870.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Wgs84

The WGS-84 coordinate reference system.

Implementations

Source

impl CoordRefSystem

pub fn validate(&self, latitude: f64, longitude: f64) -> Result<(), Error>

Validates geolocation coordinates against the selected coordinate reference system.

Examples
let crs = CoordRefSystem::Wgs84;
assert_eq!(crs.validate(52.107, 5.134), Ok(()));
assert_eq!(
    crs.validate(100.0, 5.134), // Latitude not in range `-90.0..=90.0`!
    Err(Error::OutOfRangeLatitude)
);
assert_eq!(
    crs.validate(51.107, -200.0), // Longitude not in range `-180.0..=180.0`!
    Err(Error::OutOfRangeLongitude)
);
Errors

An error is returned if the latitude/longitude is out of range with respect to the coordinate reference system.