Error

Enum Error 

pub enum Error {
    InvalidCoord(ParseFloatError),
    InvalidCoordRefSystem,
    InvalidUncertainty(ParseFloatError),
    MissingCoords,
    MissingLatitude,
    MissingLongitude,
    MissingScheme,
    OutOfRangeLatitude,
    OutOfRangeLongitude,
    OutOfRangeUncertainty,
}
Possible geo URI errors.

Variants



InvalidCoord(ParseFloatError)

The geo URI contains an unparsable/invalid coordinate.



InvalidCoordRefSystem

The geo URI contains an unsupported/invalid coordinate reference system.



InvalidUncertainty(ParseFloatError)

The geo URI contains an unparsable/invalid uncertainty distance.



MissingCoords

The geo URI contains no coordinates.



MissingLatitude

The geo URI lacks the latitude coordinate.



MissingLongitude

The geo URI lacks the longitude coordinate.



MissingScheme

The geo URI is missing a proper scheme, i.e. the prefix geo:.



OutOfRangeLatitude

The latitude coordinate is out of range of -90.0..=90.0 degrees.

This can only fail for the WGS-84 coordinate reference system.



OutOfRangeLongitude

The longitude coordinate is out of range of -180.0..=180.0 degrees.

This can only fail for the WGS-84 coordinate reference system.



OutOfRangeUncertainty

The uncertainty distance is not positive.